==> knowledgeroot_0.9.7.3.orig.tar.gz: knowledgeroot-0.9.7.3/system/language/lang_nl.php <==
<?php

$languagetoken = array(
	"nl" => array(
		"path" => "Map",
		"editcontent" => "inhoud aanpassen",
		"delcontent" => "inhoud verwijderen",
		"addfile" => "bestand toevoegen",
		"add" => "toevoegen",
		"newpage" => "nieuwe pagina toevoegen",
		"autoopen" => "de nieuwe pagina automatisch openen",
		"delpage" => "pagina verwijderen",
		"delpageask" => "Weet je het zeker dat je deze pagina wilt verwijderen?",
		"delpagefailed" => "Kan deze pagina niet verwijderen. Controleer of the inhoud op deze pagina staat!",
		"delete" => "Weet je het zeker dat je wilt verwijderen?",
		"newcontent" => "nieuwe inhoud toevoegen",
		"renamepage" => "pagina aanpassen",
		"save" => "opslaan",
		"saveandclose" => "opslaan en sluiten",
		"close" => "sluiten",
		"rename" => "naam wijzigen",
		"back" => "terug",
		"del" => "verwijderen",
		"nocontent" => "Hier is geen inhoud.",
		"user" => "Gebruiker",
		"search" => "Zoeken",
		"searchgo" => "GO",
		"nothingfound" => "Niets gevonden",
		"searchcontent" => "Inhoud",
		"searchmenu" => "Menu",
		"searchfiles" => "Bestanden",
		"searchfor" => "Zoeken naar",
		"searchshow" => "laten zien",
		"top" => "Naar boven",
		"topdescription" => "Ga naar boven",
		"movepage" => "pagina verplaatsen",
		"movecontent" => "inhoud verplaatsen",
		"moveto" => "verplaats naar",
		"welcome" => "Welkom bij Knowledgeroot",
		"emptyroot" => "naam van label mag niet leeg zijn",

		"movecontentup" => "verplaats inhoud omhoog",
		"movecontentdown" => "verplaats inhoud naar beneden",
		"contentmoved" => "inhoud verplaatst",

		"version" => "versie",

		"nouploadfolder" => "Geen upload map gevonden!",

		"tree" => array(
			"expand" => "menu uitvouwen",
			"collapse" => "menu invouwen",
			"reload" => "menu herladen",
			"hidetree" => "menu verbergen",
			"showtree" => "menu zichtbaar maken",
			"closemenu" => "menu sluiten",
			"showmenu" => "menu laten zien",
		),

		"messagebox" => array(
			"loading" => "aan het laden...",
		),

		"menu" => array(
			"roots" => "labels",
			"user" => "gebruiker",
			"options" => "opties",
			"logout" => "afmelden",
			"login" => "aanmelden",
		),

		"loginform" => array(
			"title" => "aanmelden",
			"user" => "gebruiker",
			"password" => "wachtwoord",
			"submit" => "opslaan",
		),

		"rootform" => array(
			"title" => "label aanmaken",
			"name" => "naam",
			"submit" => "aanmaken",
		),

		"rightpanel" => array(
			"user" => "gebruiker",
			"group" => "groep",
			"userrights" => "gebruikersrechten",
			"grouprights" => "groepsrechten",
			"otherrights" => "overige rechten",
			"recursiv" => "recursief veranderen",
		),

		"optionform" => array(
			"title" => "opties",
			"subtitle" => "opties aanpassen",
			"newpassword" => "nieuw wachtwoord",
			"newpassword2" => "wachtwoord bevestigen",
			"submit" => "opslaan",
			"changed" => "wachtwoord is gewijzigd",
			"failed" => "aanpassen wachtwoord niet geslaagd",
			"theme" => "thema",
			"themechanged" => "thema is gewijzigd",
			"language" => "taal",
			"languagechanged" => "taal is gewijzigd",
		),

		"userform" => array(
			"usertitle" => "gebruiker",
			"adduser" => "gebruiker toevoegen",
			"username" => "naam",
			"defaultgroup" => "standaard groep",
			"defaultrights" => "standaard rechten",
			"admin" => "beheerder",
			"rightedit" => "rechten wijzigen",
			"enabled" => "ingeschakeld",
			"action" => "actie",
			"edit" => "aanpassen",
			"delete" => "verwijderen",
			"theme" => "thema",

			"grouptitle" => "groepen",
			"addgroup" => "groep toevoegen",
			"groupname" => "naam",

			"newuser" => "nieuwe gebruiker",
			"edituser" => "gebruiker wijzigen",
			"editgroup" => "groep wijzigen",
			"password" => "wachtwoord",
			"groups" => "groep",
			"submit" => "opslaan",

			"user" => "gebruiker",
			"group" => "groep",
			"others" => "overige",

			"deluserask" => "Weet je het zeker dat je deze gebruiker wilt verwijderen?",
			"delgroupask" => "Weet je het zeker dat je deze groep wilt verwijderen?",
		),

		"email" => array(
			"notification" => "Knowledgeroot melding",
			"pathofmodification" => "Map van de aanpassing",
			"content" => "inhoud op de pagina",
			"file" => "bestands bijlage van inhoud met naam",
			"page" => "pagina",
			"was" => "was",
			"created" => "aangemaakt",
			"edited" => "gewijzigd",
			"deleted" => "verwijdert",
			"moved" => "verplaatst",
			"errormessage" => "Het is niet mogelijk een mail melding te versturen",
		),

		"yes" => "ja",
		"no" => "nee",
		"readwrite" => "lezen+schrijven",
		"read" => "lezen",
		"norights" => "geen rechten",
	),
);

?>

==> knowledgeroot_0.9.8.5.orig.tar.gz: knowledgeroot-0.9.8.5/system/language/lang_nl.php <==
<?php

$languagetoken = array(
	"nl" => array(
		"path" => "Map",
		"editcontent" => "inhoud aanpassen",
		"delcontent" => "inhoud verwijderen",
		"contenthistory" => "history",
		"addfile" => "bestand toevoegen",
		"add" => "toevoegen",
		"newpage" => "nieuwe pagina toevoegen",
		"autoopen" => "de nieuwe pagina automatisch openen",
		"delpage" => "pagina verwijderen",
		"delpageask" => "Weet je het zeker dat je deze pagina wilt verwijderen?",
		"delpagefailed" => "Kan deze pagina niet verwijderen. Controleer of the inhoud op deze pagina staat!",
		"delete" => "Weet je het zeker dat je wilt verwijderen?",
		"newcontent" => "nieuwe inhoud toevoegen",
		"renamepage" => "pagina aanpassen",
		"save" => "opslaan",
		"saveandclose" => "opslaan en sluiten",
		"close" => "sluiten",
		"contenttitle" => "Title of content (optional)",
		"collapseexpandcontent" => "Collapse/expand content",
		"lastmodifiedby" => "Last modified by",
		"guest" => "guest",
		"on" => "on",
		"rename" => "naam wijzigen",
		"back" => "terug",
		"del" => "verwijderen",
		"nocontent" => "Hier is geen inhoud.",
		"user" => "Gebruiker",
		"search" => "Zoeken",
		"searchgo" => "GO",
		"nothingfound" => "Niets gevonden",
		"searchcontent" => "Inhoud",
		"searchmenu" => "Menu",
		"searchfiles" => "Bestanden",
		"searchfor" => "Zoeken naar",
		"searchshow" => "laten zien",
		"top" => "Naar boven",
		"topdescription" => "Ga naar boven",
		"movepage" => "pagina verplaatsen",
		"movecontent" => "inhoud verplaatsen",
		"moveto" => "verplaats naar",
		"movetoroot" => "move to root",
		"welcome" => "Welkom bij Knowledgeroot",
		"emptyroot" => "naam van label mag niet leeg zijn",
		"movecontentup" => "verplaats inhoud omhoog",
		"movecontentdown" => "verplaats inhoud naar beneden",
		"contentmoved" => "inhoud verplaatst",
		"version" => "versie",
		"nouploadfolder" => "Geen upload map gevonden!",
		"editpageform" => array(
			"title" => "edit page",
			"description" => "Here you can modify page settings.",
			"name" => "pagename",
			"collapsecontent" => "Initially show all content on this page collapsed?",
			"alias" => "pagealias",
			"button" => "save changes",
		), 
		"createpageform" => array(
			"title" => "create page",
			"description" => "Here you can create a new page.",
			"name" => "pagename",
			"alias" => "pagealias",
			"button" => "create page",
			"autoopen" => "automatically open the created page",
		), 
		"tree" => array(
			"expand" => "menu uitvouwen",
			"collapse" => "menu invouwen",
			"reload" => "menu herladen",
			"hidetree" => "menu verbergen",
			"showtree" => "menu zichtbaar maken",
			"closemenu" => "menu sluiten",
			"showmenu" => "menu laten zien",
		), 
		"messagebox" => array(
			"loading" => "aan het laden...",
			"warning" => "Another user is already editing this content!",
		), 
		"menu" => array(
			"roots" => "labels",
			"user" => "gebruiker",
			"options" => "opties",
			"logout" => "afmelden",
			"login" => "aanmelden",
		), 
		"loginform" => array(
			"title" => "aanmelden",
			"user" => "gebruiker",
			"password" => "wachtwoord",
			"submit" => "opslaan",
			"loginfailed" => "You have entered the wrong user or password!",
			"loginfailedtime" => "Sie k&ouml;nnen sich erst wieder nach #RELOGINDELAY# Sekunden erneut anmelden!",
			"loginfailedblock" => "Der Account wurde wegen zu vieler fehlerhafter Loginversuchen dauerhaft gesperrt!",
		), 
		"rootform" => array(
			"title" => "label aanmaken",
			"name" => "naam",
			"submit" => "aanmaken",
			"alias" => "alias",
		), 
		"rightpanel" => array(
			"user" => "gebruiker",
			"group" => "groep",
			"userrights" => "gebruikersrechten",
			"grouprights" => "groepsrechten",
			"otherrights" => "overige rechten",
			"recursiv" => "recursief veranderen",
			"pagerights" => "pagerights",
			"pagerightsforsubpages" => "pagerights for subpages (inherit rights)",
			"enablesubinheritrights" => "enable inherit rights for subpages and contents",
			"enablesubinheritrightsenabled" => "enable edit of rights for these pages and contents",
			"disablesubinheritrights" => "disable inherit rights for subpages and contents",
		), 
		"optionform" => array(
			"title" => "opties",
			"subtitle" => "opties aanpassen",
			"newpassword" => "nieuw wachtwoord",
			"newpassword2" => "wachtwoord bevestigen",
			"submit" => "opslaan",
			"changed" => "wachtwoord is gewijzigd",
			"failed" => "aanpassen wachtwoord niet geslaagd",
			"theme" => "thema",
			"themechanged" => "thema is gewijzigd",
			"language" => "taal",
			"languagechanged" => "taal is gewijzigd",
		), 
		"userform" => array(
			"usertitle" => "gebruiker",
			"adduser" => "gebruiker toevoegen",
			"username" => "naam",
			"defaultgroup" => "standaard groep",
			"defaultrights" => "standaard rechten",
			"admin" => "beheerder",
			"rightedit" => "rechten wijzigen",
			"enabled" => "ingeschakeld",
			"action" => "actie",
			"edit" => "aanpassen",
			"delete" => "verwijderen",
			"theme" => "thema",
			"grouptitle" => "groepen",
			"addgroup" => "groep toevoegen",
			"groupname" => "naam",
			"newuser" => "nieuwe gebruiker",
			"edituser" => "gebruiker wijzigen",
			"editgroup" => "groep wijzigen",
			"password" => "wachtwoord",
			"groups" => "groep",
			"submit" => "opslaan",
			"user" => "gebruiker",
			"group" => "groep",
			"others" => "overige",
			"deluserask" => "Weet je het zeker dat je deze gebruiker wilt verwijderen?",
			"delgroupask" => "Weet je het zeker dat je deze groep wilt verwijderen?",
			"delgroupfail" => "Could not delete group. Group is in use as defaultgroup!",
			"delgroupsuccess" => "Group was deleted!",
			"delusersuccess" => "User was deleted!",
		), 
		"email" => array(
			"notification" => "Knowledgeroot melding",
			"pathofmodification" => "Map van de aanpassing",
			"content" => "inhoud op de pagina",
			"file" => "bestands bijlage van inhoud met naam",
			"page" => "pagina",
			"was" => "was",
			"created" => "aangemaakt",
			"edited" => "gewijzigd",
			"deleted" => "verwijdert",
			"moved" => "verplaatst",
			"action" => "Action",
			"errormessage" => "Het is niet mogelijk een mail melding te versturen",
			"author" => "author",
			"date" => "date",
		), 
		"yes" => "ja",
		"no" => "nee",
		"readwrite" => "lezen+schrijven",
		"read" => "lezen",
		"norights" => "geen rechten",
		"newpagename" => "page name",
		"newpagealias" => "page alias",
		"moveclose" => "close window",
		"maxfilesize" => "Cannot add file. File is to big!",
	), 
);

?>
